pyramid_yards
=============

An http parameters validator for the Pyramid Web framework

It adds a "yards" attribute to the pyramid request object,
containing every validated parameter using colander schemas.

This lib has been inspired by the cornice ``validated`` property,
but the implementation differ.
